======
ksfest
======


.. image:: https://img.shields.io/pypi/v/ksfest.svg
        :target: https://pypi.python.org/pypi/ksfest

.. image:: https://img.shields.io/travis/oristides/ksfest.svg
        :target: https://travis-ci.org/oristides/ksfest

.. image:: https://readthedocs.org/projects/ksfest/badge/?version=latest
        :target: https://ksfest.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Python package to check data quality using  ks tests


* Free software: MIT license
* Documentation: https://ksfest.readthedocs.io.


Features
--------




Credits
-------


This package was created with Cookiecutter_

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
